mafw.db.fields
==============

.. automodule:: mafw.db.fields

   
   .. rubric:: Classes

   .. autosummary::
   
      FileChecksumField
      FileChecksumFieldAccessor
      FileNameField
      FileNameFieldAccessor
      FileNameListField
   